# S3 Immutable Bucket Cleanup Tool - Simplified Version

This is a simplified version of the S3 bucket cleanup tool that automatically removes objects where the current version is a delete marker, while respecting Object Lock retention policies.

## Features

- Automatic configuration from `config.ini` file
- Respects Object Lock retention policies
- Bulk deletion with configurable batch sizes
- Comprehensive logging
- Creates JSON files for each delete batch
- No user interaction required

## Setup

1. Copy `config.ini.template` to `config.ini`
2. Edit `config.ini` with your S3 configuration:
   ```ini
   [S3]
   ENDPOINT_URL=https://your-s3-endpoint.com
   ACCESS_KEY=your_access_key_here
   SECRET_KEY=your_secret_key_here
   BUCKET_NAME=your_bucket_name_here
   ```

## Usage

Simply run the script:
```bash
python cleanup_immutable_bucket_simple.py
```

The script will:
1. Read configuration from `config.ini`
2. Connect to the S3 bucket
3. List all objects and identify those with delete markers as current version
4. Check retention policies for each object
5. Delete objects that are not protected by retention
6. Log all operations to console and log file

## Output

- **Logs**: Created in `log/` directory with timestamp
- **Delete batches**: JSON files created in `delete-objects/` directory
- **Console output**: Real-time progress and summary statistics

## Requirements

- Python 3.6+
- boto3 library
- Valid S3 credentials and permissions
